function [Z,A,t,Zreq,wh,wt,ft,fl,s,l,i,tp] = FISCR(zl,c)
% (P,s,l) --> power kW, spacing m, span m
%--------------------------------------------------------------------------
% what: FISCR design rules, 1a super, longitudinally framed ice belt.
% Finding required plate thickness (t) [mm], shear area (A) [cm^2],
% section modulus (Z) [cm^3], spacing (s) [m], span (l) [m], rest [mm]
% Date: 11 April 2013
% Author: Karoline Neumann
%--------------------------------------------------------------------------



design = 2;     % 1 = FISCR, 2 = external req, zl [N] from designloadreturn

framing = 1;    % 1 = longitudinal, 2 = transverse

transl = [
0.23;
0.46;
0.69;
0.92];

longs = [
3.21;
2.98;
2.75;
2.52;
2.29;
2.06;
1.83;
1.6;
1.37;
1.15;
0.92];


if design==1
    sigmay = 235;       % [MPa] assuming normal strength hull structural steel
else
    sigmay=289.9;       % [MPa] my for distrubution
end

if framing ==1
    l = longs(15-c);    % [m] frame spacing
    s = 0.3;    % [m] frame span
else
    l = 2.8;
    s = transl(c);
end

    
    % plate thickness
   
    if s>0.35 && framing ==1
        disp('s too  big')
    end
    
    delta = 159*24.6*9.4*0.7*1.25;          % rho = 1.25 t/m^3  length= 159 breadth=24.6 draft=9.4  assumed block coef
    P = 4000;                   % [kW] check this number for credo
    k = sqrt(delta*P)/1000;
    
    if k<=12
        a = 8;
        b = 2.14;
    elseif k>12
        a = 2;
        b = 286;
    end
    
    c1 = 1;             % a factor which takes account of the probability that the design ice pressure occurs in a certain region of the hull for the ice class in question. is =1 is 1a super
    
    if framing == 1
        la = l;           % [m] longitudinal frame span
    else
        la = s;         % [m] transversal frame spacing
    end
    
    ca = (47-5*la)/44;  % a factor which takes account of the probability that the full length of the area under consideration will be under pressure at the same time
    
    if ca>1 || ca <0.6
        disp('ca failure')
    end
    
    p0 = 5.6;           % MPa nominal ice pressure
    cd = (a*k+b)/1000;  % factor taking into account engine output
    p = cd*c1*ca*p0;    % [MPa] ice pressure according to 4.2.2
    p_PL = 0.75*p;
    h = 0.35;
    
    if h/s < 1
        f2 = 0.6 + 0.4/(h/s);
    elseif h/s>=1 || h/s<1.8
        f2 = 1.4-0.4*(h/s);
    else
        disp('h/s failure')
    end
    
    f1 = 1.3 - 4.2/(h/s + 1.8)^2;
    if f1>1
        f1 =1;
    end
    
    tc = 2;             % [mm]
    
    if framing ==1
        t = 667*s*sqrt(p_PL/(f2*sigmay))+tc; % mm
    else
        t = 667*s*sqrt((f1*p_PL)/sigmay)+tc; % mm
    end
    
if design==1
    
    % section modulus
    f3 = 1-0.2*(h/s);
    f4 = 0.6;
    m = 13.3;
    m0 = 5.7;   % assuming b.c
    mt = (7*m0)/(7-5*(h/l));
    
    if framing ==1
        Zreq = (f3*f4*p*h*l^2*10^6)/(m*sigmay);        % [cm^3] section modulus
        Areq = (sqrt(3)*f3*p*h*l*10^4)/(2*sigmay);     % {cm^2] shear area when attached to supporting structure by brackets
    else
        Zreq = ((p*s*h*l)/(mt*sigmay))*10^6;           % [cm^3]
        Areq = 0;
        
    end
    
else
    M = (zl*l*1000)/8;          % moment [N mm]
    Zreq = M/sigmay;            % required section modulus [mm^3]
    Zreq = Zreq/10^3;           % [cm^3]
    Areq = 0;  
end


    % structure according to requirement
    

    s = s*1000;         %  plate flange width (spacing) now in mm
    l = l*1000;
    tp = t;
    
    % dim [ web hight | flange length | web thickness | flange thickness ] [mm]
    dim = [200 90 9 12;
        250 90 9 13;
        250 90 10.5 15;
        250 90 11.5 16;
        300 100 10.5 15;
        300 100 11.5 16;
        325 120 10.5 14;
        325 120 11.5 15;
        350 120 10.5 16;
        350 120 11.5 18;
        400 120 11.5 23];
    
    
    for i = 1:length(dim)
        
        
        if dim(i,3)>t                   % if web is bigger than plate thickness requirement from FSICR
            tp = dim(i,3);              % such that plate is never smaller than web thickness
        elseif t>dim(i,3)
            tp = t;
        end
        
        t0 = (s*tp*(tp/2) + dim(i,1)*dim(i,3)*(tp+dim(i,1)/2) + dim(i,2)*dim(i,4)*(tp+dim(i,1)+dim(i,4)/2)) / (s*tp + dim(i,1)*dim(i,3) + dim(i,2)*dim(i,4));
        I_steiner = (s*tp^3)/12 + (dim(i,3)*dim(i,1)^3)/12 + (dim(i,2)*dim(i,4)^3)/12;
        I_usteiner = (t0-tp/2)^2*s*tp + (t0 -(tp+dim(i,1)/2))^2*dim(i,1)*dim(i,3) + (t0-(tp+dim(i,1)+dim(i,4)/2))^2*dim(i,2)*dim(i,4);
        I_tot = I_steiner + I_usteiner;                     % [mm^4]
        Z = I_tot/abs(t0-(tp+dim(i,1)+dim(i,4)));           % [mm^3]
        Z = Z/10^3;                                         % [cm^3]
        A = tp*s+dim(i,1)*dim(i,3)+dim(i,2)*dim(i,4);       % [mm^2]
        A = A/10^2;                                         % [cm^2]
        
        if Z > Zreq && A > Areq
            wh = dim(i,1);
            fl = dim(i,2);
            wt = dim(i,3);
            ft = dim(i,4);
            return
        end
       
    end
    


