function [Pep,Pel,zp,zl]=designloadreturn(my,rep,designzp,designzl,alpha,x0e,col)

%--------------------------------------------------------------------------
% what: given a design scenario finds probability of exceedance, Pep,Pel. 
% Given return period, rep [years], finds corresponding pressure and load.
% my is nr of expected hits per year from scenario. plots designload vs rep
% date: 11. April 2013
% Author: Karoline Neumann
%--------------------------------------------------------------------------
cmap=jet(14);
lambda = 25;
x0e = x0e*(25/1000);  % MPa full scale
alpha = alpha*(25/1000); % MPa full scale

x1 = alpha*log(my);
Fzp = exp(-exp(-(designzp-x0e-x1)/alpha));                                 % extreme cdf. given yield strength (275 MPa) find corresponding probability
Pep = 1-Fzp;
zp = (x0e + alpha*(-log(-log(1-(1/rep)))+log(my)));                          % scenario rep pressure [MPa] full scale

area = (0.4399/48)*(0.4801/44)*lambda^2;                                   % area corresponding to one cell full scale [m^2]
Fzl = exp(-exp(-((designzl/(col*area*1000^2))-x0e-x1)/alpha));             % designzl in [N] divided with mm^2 to obtain MPa
Pel = 1-Fzl;
zl = zp*10^6*col*area;                                                     % scenario rep load [N] full scale

rep = 1:10000;
ZP = x0e + alpha*(-log(-log(1-(1./rep)))+log(my));
ZL = ZP.*10^6.*col.*area;

leg = semilogx(rep,ZL,'color',cmap(col,:));
xlabel('return period [year]')
ylabel('design load [N]')
title(['design load vs return period for area corresponding to ',num2str(col),' cells'])

hold on