function [MTCtevent,MELtevent,MTCevent,MELevent] = eventasess(timevent,spevent,nbigload)

%--------------------------------------------------------------------------
% What: function plotting force vs frames, spatial pressure area and 3d 
% colorbar for timevent corresponding to max triggered cell and max sum of 
% event
% Author: Karoline Neumann
% Last updated: 19 Feb 13
%--------------------------------------------------------------------------


%--------------------------------------------------------------------------
% starting with max triggered cell
%--------------------------------------------------------------------------

MaxTrigCell = sortrows(spevent,-2);                                         % 
MaxTrigCell = MaxTrigCell(1,:);                                             % | eventnr | value | frame | i | j | for max triggered cell
MTCevent = MaxTrigCell(1,1);                                                % eventnr for max triggered cell
[MTCr,MTCc]= find(timevent(:,2)==MTCevent);                                 % row in timevent for mac triggered cell event
MTCtevent = timevent(MTCr,1);                                               % timevent corresponding to max triggered cell event
[r,c] = find(timevent(:,1)==MTCtevent);                                     % rows corresponding to max triggered cell timevent in timevent
MTCevents = timevent(r,2);                                                  % all events belonging to max triggered cell timevent
first = find(spevent(:,1)==MTCevents(1));
last = find(spevent(:,1)==MTCevents(length(MTCevents)));
first = spevent(first,3);
last = spevent(last,3);
MTCplot = zeros(first-last,3);


i = 1;
for t = 1:length(MTCevents)                                                 % go through events belonging to the timevent of max triggered cell 
    [r] = find(spevent(:,1)==MTCevents(t));                                 % row of event in spevent
    frame(t) = r(1);                                                        % rows of event in spevent
    
    MTCplot(i,1) = MTCevents(t);                                            % assign eventnr to first row in MTCplot
    [r,c] = find(nbigload(:,1)==MTCevents(t));                              % find row in nbigload corresponding to each eventnr
  %  MTCplot(i,3) = nbigload(r,3)/nbigload(r,2) + MTCplot(i,3);              % use this row to pick out the corresponding p sum/nr trig cells for that event in nbigload and assign to column 3 in MTCplot
    [r,c] = find(spevent==MTCevents(t));                                    % overwrite row and find row in spevent corresponding to each event (can be several)
    MTCplot(i,2) = spevent(r(1),3);                                         % one event only has one frame, pick one and assign this frame to MTCplot
    
    
    for k = 1:length(r)                                                 % go through all trig cells in that event
        if spevent(r(k),2)>MTCplot(i,3)                                 % keep the biggest
            MTCplot(i,3)=spevent(r(k),2);
        end
    end
    
     if t~=1 && spevent(frame(t),3)==spevent(frame(t-1),3)                  % if the frame of the previous event is equal from the frame of this event
 
     else                                                                   % if there's a new frame     
        i = i+1;
     end
    

   
end

figure
plot(MTCplot(:,2),MTCplot(:,3))
title('Biggest single triggered cells in the timevent containing the biggest triggered cell')
xlabel('timeframe')
ylabel('Max triggered cells of each timevent [kPa]')

%--------------------------------------------------------------------------
% Making spatial pressure-area curve for event with max triggered cell
%--------------------------------------------------------------------------
spatialplot(timevent,spevent,MTCtevent,MTCevent)
title('spatial pressure-area curve for event with max triggered cell')
xlabel('area m^2') % check correct unit here
ylabel('pressure kPa') % check if correct

%--------------------------------------------------------------------------
% plotting 3d colored bar of event for max triggered cell
%--------------------------------------------------------------------------
figure
colorbarplot(MTCevent,spevent)
title('Max Triggered Cell event')
zlabel('pressure kPa')


%--------------------------------------------------------------------------
% max sum of event
%--------------------------------------------------------------------------

MaxEventLoad = nbigload(1,3); %pressure
MELevent = nbigload(1,1);
[MELr,MELc] = find(timevent(:,2)==MELevent);
MELtevent = timevent(MELr,1);
[r,c] = find(timevent(:,1)==MELtevent);
MELevents = timevent(r,2);
MELplot = zeros(length(unique(MELevents)),3);
first = find(spevent(:,1)==MELevents(1));
last = find(spevent(:,1)==MELevents(length(MELevents)));
first = spevent(first,3);
last = spevent(last,3);
MELplot = zeros(first-last,3);

i = 0;
for t = 1:length(MELevents)
     [r] = find(spevent(:,1)==MELevents(t));                                 % rows of event in spevent
    frame(t) = r(1);
    if t~=1 && spevent(frame(t),3)==spevent(frame(t-1),3)                  % if the frame of the previous event is equal from the frame of this event
                                                                   
    else
        i = i+1;
    end
    
    MELplot(i,1) = MELevents(t);
    [r,c] = find(nbigload==MELevents(t));
    MELplot(i,3) = nbigload(r,4) + MELplot(i,3);
    [r,c] = find(spevent==MELevents(t));
    MELplot(i,2) = spevent(r(1),3);
    
end


figure
plot(MELplot(:,2),MELplot(:,3))
title('Max Event Load')
xlabel('timeframe')
ylabel('load N') % check unit


%--------------------------------------------------------------------------
% Making spatial pressure-area curve for timevent containing biggest event
%--------------------------------------------------------------------------
spatialplot(timevent,spevent,MELtevent,MELevent)
title('spatial pressure-area curve for timevent containing biggest event')
xlabel('area m^2') % check correct unit here
ylabel('pressure kPa') % check if correct



%--------------------------------------------------------------------------
% plotting 3d colored bar of max load event
%--------------------------------------------------------------------------
figure
colorbarplot(MELevent,spevent)
title('Max load event')
zlabel('pressure kPa')

%--------------------------------------------------------------------------
% max sum of timeevent (DOESN'T MAKE SENSE-> f(freq_obervations)
%--------------------------------------------------------------------------
% 
% MaxTimeEvent = fevent(1,2);
% MTEtevent = fevent(1,1);
% [r,c] = find(timevent(:,1)==MTEtevent);
% MTEevents = timevent(r,2);
% 
% 
% for i = 1:length(MTEevents)
%     MTEplot(i,1) = MTEevents(i);
%     [r,c] = find(nbigload==MTEevents(i));
%     MTEplot(i,3) = nbigload(r,4);
%     [r,c] = find(spevent==MTEevents(i));
%     MTEplot(i,2) = spevent(r(1),3);
%     
% end
% 
% figure
% plot(MTEplot(:,2),MTEplot(:,3))
% title('Max Time Event')



