function [x0p,alphap] = graph(maxevents,mcells)

%--------------------------------------------------------------------------
% what: function plotting Z values (pressure) probability of exceedance
% with weibull plotting position and exponential distribution fitted to
% tail. Also accounts for exposure. full scale is MPa and N
% Date: 12 March 13
% last updated: 9 April 13
% Author: Karoline Neumann
%--------------------------------------------------------------------------

%--------------------------------------------------------------------------
% pressure
%--------------------------------------------------------------------------


N = length(maxevents);
curve = zeros;

maxevents = sortrows(maxevents,-2);                                         % dataset is ranged in descending order



for i = 1:length(maxevents)
    curve(i,1) = maxevents(i,2);
    curve(i,2) = (i/(N+1));                                                
    curve(i,3) = (i/(mcells*N+1));
    curve(i,4) = length(maxevents)-i;
end


plot(curve(:,1),-log(curve(:,2)),'+')
hold on

plot(curve(:,1),-log(curve(:,3)),'*')                                       % accounted for exposure model scale


x = 1:150;
y = exp(-(x--36)/21.6);                                                     % x0 = -36kPa alpha = 21.6 --> fullscale: x0 = -0.9 alpha = 0.54
Y = exp(-(x--170)/21.6);


plot(x,-log(y))
plot(x,-log(Y),'--')

xlabel('pressure kPa')
ylabel('-log(p_e)')
title('model scale')
legend('raw data','raw data accounted for exposure','fit to raw data','fit to adjusted data')


%--------------------------------------------------------------------------
% scale up
%--------------------------------------------------------------------------

figure
plot((25*curve(:,1))/1000,-log(curve(:,2)),'+')
hold on
plot((25*curve(:,1))/1000,-log(curve(:,3)),'*')


x = (1*25)/1000:0.01:(25*150)/1000;
y = exp(-(x--0.9)/0.54);
Y = exp(-(x--4.25)/0.54);

x0p = -4.25;
alphap = 0.54;

polarsea = exp(-(x-0.889)/0.412);
p = plot(x,-log(polarsea));
plot(x,-log(y))
plot(x,-log(Y),'--')
xlabel('pressure MPa')
ylabel('-log(p_e)')
title('full scale')
set(p,'color','red')
legend('data not acounted for exposure','data accounted for exposure','polarsea best fit line tail acc exposure')

figure
plot((25*curve(:,1))/1000,curve(:,2),'+')
hold on
plot(x,y)
title('probability of exceedance not accounted for exposure, Full scale pressure')
xlabel('pressure MPa')
ylabel('p_e')

figure
plot((25*curve(:,1))/1000,curve(:,3),'*')
hold on
plot(x,Y)
title('probability of exceedance accounted for exposure, Full scale pressure')
xlabel('pressure MPa')
ylabel('p_e')

figure
plot((25*curve(:,1))/1000,1-curve(:,2),'+')
hold on
plot(x,1-y)
title('CDF not accounted for exposure, Full scale pressure')
xlabel('pressure MPa')
ylabel('CDF')

figure
plot((25*curve(:,1))/1000,1-curve(:,3),'*')
hold on
plot(x,1-Y)
title('CDF accounted for exposure, Full scale pressure')
xlabel('pressure MPa')
ylabel('CDF')

%--------------------------------------------------------------------------
% forces full scale
%--------------------------------------------------------------------------
% 
% zload = sortrows(zload,-1);
% zload = 25^3*zload;                                                           % converting to full scale [N] assuming (rho_f/rho_m) constant
% N = length(zload);
% onecell = (0.4801/48)*(0.4399/44);                                          % ignoring 0.65 because force acting on entire cell
% totalarea = mcells*onecell;
% maxloadarea = 32;
% meanloadarea =2.6070;
% mmax=totalarea/(maxloadarea*onecell);
% mmean = totalarea/(meanloadarea*onecell);
% 
% clear curve
% for i = 1:N
%     curve(i,1) = zload(i);
%     curve(i,2) = (i/(N+1));
%     curve(i,3) = (i/(mcells*N+1));                                           
%     curve(i,4) = N-i;
%     curve(i,5) = (i/(mmax*N+1));
%     curve(i,6) = (i/(mmean*N+1));
% end
% 
% figure
% plot(curve(:,1),-log(curve(:,2)),'+')
% hold on
% plot(curve(:,1),-log(curve(:,3)),'*')
% plot(curve(:,1),-log(curve(:,5)),'o')
% plot(curve(:,1),-log(curve(:,6)),'x')
% 
% 
% 
% legend('not accounted for exposure','accounted for exposure as if 1 cell','accounted for exposure as if max area', 'accounted for exposure as if mean area')
% title('full scale max event forces weibull probability plot')
% xlabel('forces [N]')
% ylabel('-log(p_e)')
% 
% 
% x = 1.8*10^7:2.5*10^7;
% plot(x,-log(exp(-(x--0)/(1.5*10^6))));
% 
% 
% x0l = -0.5*10^6;
% alphal = 10^6;
% 
% 
% figure
% plot(curve(:,1),1-curve(:,2),'+')
% title('CDF not accounted for exposure, Full scale loads')
% xlabel('force [N]')
% ylabel('CDF')
% 
% %--------------------------------------------------------------------------
% % forces from max event method pressures, acting on one cell
% %--------------------------------------------------------------------------
% 
% forcemodel = maxevents(:,2)*1000*(0.4801/48)*(0.4399/44);                  % assuming pressure acts evenly over entire cell area, not only cencoring part.
% forcefull = forcemodel*25^3;
% 
% forcefull = sortrows(forcefull,-1);
% N = length(forcefull);
% clear curve
% 
% for i = 1:length(forcefull)
%     curve(i,1) = forcefull(i);
%     curve(i,2) = (i/(N+1));                                                 % question: should this N be before or after treshold? maybe just quit the treshold? I think if treshold, N after. hm... ask
%     curve(i,3) = (i/(mcells*N+1));
%     curve(i,4) = N-i;
% end
% 
% figure
% 
% plot(curve(:,1),-log(curve(:,2)),'+')
% hold on
% 
% plot(curve(:,1),-log(curve(:,3)),'*')  
% 
% 
% x = 0:2.5*10^5;
% y = exp(-(x--0.07*10^5)/(0.27*10^5));
% Y = exp(-(x--1.75*10^5)/(0.27*10^5));
% 
% x0lp = -1.75*10^5;
% alphalp = 0.27*10^5;
% 
% plot(x,-log(y))
% plot(x,-log(Y))