function [spa] = pacurve(spevent)

%--------------------------------------------------------------------------
% what: function going through all triggered cells and for each cell saves
% p-a values. If higher p value found for an area this will owerwrite 
% existing ones. Plotting local pressure area curve. 
% spa: |trig cells n (area)| subsequent n highest p| internal av. pressure|
% Date: 13 March 13, updated 2nd July
% Author: Karoline Neumann
%--------------------------------------------------------------------------

m = 1; % counting nr of triggered cells within an event
epa(1,2) = spevent(1,2);
epa(1,1) = 1;
event = spevent(1,1);


for i = 2:length(spevent)
    if spevent(i,1) == event                                                % if it's the same event as previous
        m = m+1;
        epa(m,2) = spevent(i,2);
        
    else                                                                    % if it's a new event
        epa = sortrows(epa,-2);
        epa(1,1) = 1;
        epa(1,3) = epa(1,2);
        for t = 2:m
            epa(t,1)=epa(t-1,1)+1;
            epa(t,3) = sum(epa(1:t,2))./epa(t,1);                           % average pressure for each area
        end
        
        if event == spevent(1,1)                                            % if it's the first event
            spa = epa;
        else                                                                % if it's not the first event
            E = size(epa);
            S = size(spa);
            
            for j = 1:E(1,1)                                                % going through epa
                if  S(1,1)<j                                                % if that area does not exist yet in spa
                    spa(j,2) = epa(j,2);                                    % assign unassigned areas
                    spa(j,1) = epa(j,1);
                    spa(j,3) = epa(j,3);
                elseif epa(j,3) > spa(j,3)
                    spa(j,2) = epa(j,2);                                    % overwrite the old value
                    spa(j,1) = epa(j,1);
                    spa(j,3) = epa(j,3);
                    
                end
            end
        end
        
        epa = zeros(1,3);
        event = spevent(i,1);
        m = 1;
        epa(1,2) = spevent(i,2);
        epa(1,1) = 1;
    end
end

figure
plot(spa(:,1)*0.010911*9.16458*10^-3,spa(:,3),'*')
title('model scale pressure area curve')
xlabel('area [m^2]')
ylabel('pressure [kPa]')

hold on

x = 0:0.1*10^-3:3.5*10^-3;
plot(x,1.518*x.^-0.5016)

legend('model scale p-a data','fit to data: p = 1.518*x^{-0.5016}')

figure
a1 = plot(spa(:,1)*(0.010911*9.16458*10^-3)*25^2,(spa(:,3)*25)/1000,'*');   % scale up area*25^2 and pressure *25 divided by 1000 to obtain MPa from kPa
title('full scale pressure area curve.')
xlabel('area [m^2]')
ylabel('pressure [MPa]')

hold on

a = 0:0.01:2;
%p1 = 8.1*a.^-0.5;
%b1 = plot(a,p1);
c1 = plot(a,0.9586*a.^-0.5016);                                                   
%set(b1,'color','red');                                                                            

la = linspace(0.6,4.12);
ca = (47-5*la)/44;
p = 0.0929*1.*ca*5.6;
al = 0.35.*la;
d2 = loglog(al,p);
set(d2,'color','green');

leg1 = legend('data','k = 0.9586, n = -0.5016 fit','FSICR design pressure for frames');
axis([0 2 0 7]);

figure

a2 = loglog(spa(:,1)*(0.010911*9.16458*10^-3)*25^2,(spa(:,3)*25)/1000,'*');
title('log log full scale pressure area curve.')
xlabel('area [m^2]')
ylabel('pressure [MPa]')

hold on
a = 0:0.01:5;
%p2 = 8.1*a.^-0.5;
%b2 = loglog(a,p2);


c2 = loglog(a,0.9586*a.^-0.5016);                                                   % found using fit(x,y,'power1') 95% conficende  a =0.08291  (0.04292, 0.1229) 
%set(b2,'color','red');                                                                            %  b =       -1.21  (-1.372, -1.047)


leg1 = legend('data','k = 0.9586, n = -0.5016 fit');
axis([ min(spa(:,1))*(0.010911*9.16458*10^-3)*25^2 5 0 5 ])

figure

a3 = semilogx(spa(:,1)*(0.010911*9.16458*10^-3)*25^2,(spa(:,3)*25)/1000,'*');
title('semilog full scale pressure area curve.')
xlabel('area [m^2]')
ylabel('pressure [MPa]')

hold on
a = 0:0.01:5;
%p2 = 8.1*a.^-0.5;
%b2 = semilogx(a,p2);


c2 = semilogx(a,0.9586*a.^-0.5016);                                                   % found using fit(x,y,'power1') 95% conficende  a =0.08291  (0.04292, 0.1229) 
%set(b2,'color','red');                                                                            %  b =       -1.21  (-1.372, -1.047)
leg1 = legend('data','k = 0.9586, n = -0.5016 fit');
axis([ min(spa(:,1))*(0.010911*9.16458*10^-3)*25^2 5 0 5 ])
