function [Ultload_my,Ultload_std,Z] = strengthdist(wt,wh,ft,fl,s,tp,l)

%--------------------------------------------------------------------------
% what: given structure and steel, finds strength distribution parameters
% [N] assuming normal distribution. l = span [m], s =spacing [m], rest [mm]
% Date: 11 April 2013
% Author: Karoline Neumann
%--------------------------------------------------------------------------

design = 1; % 1 = elastic, 2 = plastic

sigmay_my = 289.9;           % MPa
sigmay_std = 22.36;          % MPa
%s = s*1000;                  %  plate flange width (spacing) now in mm
%l = l*1000;                  % span now in mm


if design ==1
    
     % dim [ web hight | flange length | web thickness | flange thickness ] [mm]
    dim = [wh fl wt ft ];
    
    t0 = (s*tp*(tp/2) + dim(1)*dim(3)*(tp+dim(1)/2) + dim(2)*dim(4)*(tp+dim(1)+dim(4)/2)) / (s*tp + dim(1)*dim(3) + dim(2)*dim(4));
    I_steiner = (s*tp^3)/12 + (dim(3)*dim(1)^3)/12 + (dim(2)*dim(4)^3)/12;
    I_usteiner = (t0-tp/2)^2*s*tp + (t0 -(tp+dim(1)/2))^2*dim(1)*dim(3) + (t0-(tp+dim(1)+dim(4)/2))^2*dim(2)*dim(4);
    I_tot = I_steiner + I_usteiner;                     % [mm^4]
    Z = I_tot/abs(t0-(tp+dim(1)+dim(4)));               % [mm^3]
    
    M_my = Z*sigmay_my;                                 % [N mm]
    M_std = Z*sigmay_std;
    
    Ultload_my = (8*M_my)/l;                        % [N] assuming beam fixed at both ends concentrated load at center
    Ultload_std = (8*M_std)/l;                      % [N]
    
else

Ap =s*tp;
Aw = wt*wh;
Af = ft*fl;


if Ap > Aw + Af
    C1 = (Ap-Aw-Af)/(2*Ap);
    C2 = C1^2 - C1 + 0.5;
    g = C1*tp;
    Zflange = Af*(wh+g+0.5*ft);
    Zweb = Aw*(0.5*wh+g);
    Zplate = Ap*tp*C2;
else
    C1 = (-Ap+Aw+Af)/(2*Aw);
    C2 = C1^2 - C1 + 0.5;
    g = C1*wh;
    Zflange = Af*(wh-g+0.5*ft);
    Zweb = Aw*wh*C2;
    Zplate = Ap*(g+0.5*tp);
end


Zp = Zflange + Zweb + Zplate;                    % based on hughes [mm^3]
Mp_my = (Zp*sigmay_my)/1000;                     % plastic moment [Nm]
Mp_std = (Zp*sigmay_std)/1000;          	 % [Nm]

Ultload_my = (8*Mp_my)/l;                        % [N]
Ultload_std = (8*Mp_std)/l;                % [N]

end