function [pa,areas,maxareas,ipmaxareas,ipa] = totcontapa(spevent)

%--------------------------------------------------------------------------
% what: function making pressure area curve considering average pressure
% over total measured contact area for each spatial event. lower values for
% each area is overwritten. model scale. pa: | pressure [kPa] | area [m^2]|
% when: 25 June 2013
% Author: Karoline Neumann
%--------------------------------------------------------------------------

ea = 1; % counting nr of triggered cells within a spatial event
event =spevent(1,1);
ep = spevent(1,2);
pa = zeros;
areas = zeros(1,32);
emaxp = 0; % event single max pressure cell

for i = 2:length(spevent)
    if spevent(i,1) ==event                                                 % if it's the same spatial event as previous
        ea = ea+1;
        ep = ep + spevent(i,2);
        if spevent(i,2) > emaxp
            emaxp = spevent(i,2);
        end
    else                                                                    % if it's a new spatial event
        areas(ea) = areas(ea)+1;                                            % counting occurences of total measured areas
        if event ==spevent(1,1)                                             % if it's the first spatial event
            pa(ea,1) = ep;
            pa(ea,2) = ea;
            ipa(ea,1) = emaxp;
            ipa(ea,2) = ea;
            
        else                                                                % if it's not the first spatial event
            check1 = find(pa(:,2)==ea);
            check2 = isempty(check1);
            check3 = find(ipa(:,2)==ea);
            check4 =isempty(check3);
            if check2 ==0                                                   % if that area exists from before
                if pa(check1,1) < ep                                        % if this spatial event has larger av. pressure than all previous spatial events the same size
                    pa(ea,1) = ep;                                          % overwrite
                    pa(ea,2) = ea;
                    maxareas(ea,1) = spevent(i-1,1);
                    maxareas(ea,2) = ep;
                end
                if ipa(check3,1) < emaxp
                    ipa(ea,1) = emaxp;
                    ipa(ea,2) = ea;
                    ipmaxareas(ea,1) = spevent(i-1,1);
                    ipmaxareas(ea,2) = emaxp;
                end
            else                                                            % if that area does not exist form before
                pa(ea,1) = ep;                                              % assign value to that area
                pa(ea,2) = ea;
                maxareas(ea,1) = spevent(i-1,1);
                maxareas(ea,2) = ep;
                
                ipa(ea,1) = emaxp;                                         % assign value to that area
                ipa(ea,2) = ea;
                ipmaxareas(ea,1) = spevent(i-1,1);
                ipmaxareas(ea,2) = emaxp;
            end
            
        end
        event = event +1;
        ea = 1;
        ep = spevent(i,2);
        emaxp = 0;
    end
end
    
pa(:,1) = pa(:,1)./pa(:,2);
pa(:,2) = pa(:,2).*(0.4399/48).*(0.4801/44);


plot(pa(:,2),pa(:,1),'*')

x = 0:0.1*10^-3:(3.5*10^-3);
p = 2.057.*x.^-0.4244;                                                       % shifted exponential seems to fit good. 

hold on

plot(x,p)
title('Average pressure over total measured contact area considering all spatial events')
legend('model scale p-a data','fit to data: p=2.057*x^{-0.4244}')
xlabel('area [m^2]')
ylabel('pressure [kPa]')

figure
areas = log(areas);
bar(areas);
title('log plot for occurences of individual spatial event total measured contact areas')
xlabel('Nr. of contact spots')
ylabel('natural log of occurences')

